@@ -87,7 +87,7 @@ fun _transform ( ArrayRef $data) {
 }
 
 fun exec_commands ( Str $c, @data ) {
-    open my $proc, "| /usr/bin/gnuplot";
+    open my $proc, "|gnuplot";
     my $tmp = File::Temp->new();
     my $tfn = $tmp->filename();
     write_data( $tfn, @data );
